@@ -1,9 +1,13 @@
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 
+
+from enums import DevelopmentEnvironment
+from environment import Environment
+from singleton import Singleton
+from enums import MESSAGE_TYPE
 from abstract import Base
 from enums import CODING
 from enums import MUSTACHE
-from enums import MESSAGE_TYPE
 from templateModule import TemplateModule
 from templateFile import TemplateFile
 from templateFolder import TemplateFolder
